Skip to contents

Adds multiple shape descriptors to every streamline inside a bundle.

Arguments

x

A bundle object.

descriptors

A character vector of shape descriptors to add. Defaults to all available descriptors: c("euclidean_length", "curvilinear_length", "sinuosity", "curvature", "torsion").

Value

A bundle with the specified shape descriptors added to the @streamline_data or @point_data slots of each streamline as appropriate.