Computes the symmetric Hausdorff distance between two streamline objects based on their 3-D coordinate matrices.
Arguments
- x
A streamline object.
- y
A streamline object.
Computes the symmetric Hausdorff distance between two streamline objects based on their 3-D coordinate matrices.
A streamline object.
A streamline object.