Test whether an object is a streamline
Value
TRUE if x is of class streamline, otherwise FALSE.
Examples
sl <- streamline(points = cbind(X = 1:5, Y = 1:5, Z = 1:5))
is_streamline(sl) # TRUE
#> [1] TRUE
is_streamline(42) # FALSE
#> [1] FALSE
Test whether an object is a streamline
TRUE if x is of class streamline, otherwise FALSE.
sl <- streamline(points = cbind(X = 1:5, Y = 1:5, Z = 1:5))
is_streamline(sl) # TRUE
#> [1] TRUE
is_streamline(42) # FALSE
#> [1] FALSE