add_shape_descriptors() method for streamline objects
Source: R/shape.R
add_shape_descriptors-fiber-streamline-method.RdAdds multiple shape descriptors to a single streamline object.
Arguments
- x
A streamline object.
- descriptors
A character vector of shape descriptors to add. Defaults to all available descriptors:
c("euclidean_length", "curvilinear_length", "sinuosity", "curvature", "torsion").
Value
A streamline with the specified shape descriptors added to the
@streamline_data or @point_data slots as appropriate.