get_sinuosity() is a function that computes the ratio of curvilinear
length to Euclidean length for a streamline object, with a value of
1 indicating a perfectly straight streamline and larger values indicating
greater curviness.
Arguments
- x
A streamline object.
Examples
sl <- streamline(points = cbind(X = runif(10), Y = runif(10), Z = runif(10)))
get_sinuosity(sl)
#> [1] 8.138817