Reparametrize a streamline or bundle onto a uniform arc-length grid
Source:R/parametrize.R
reparametrize.RdResamples the 3-D coordinates (and any @point_data attributes) of a
streamline or every streamline inside a bundle onto a uniform
arc-length grid using linear interpolation.
Arguments
- x
A streamline or bundle object.
- n_points
Number of equally-spaced arc-length points to use.
For a single streamline, defaults to
nrow(x@points).For a bundle, defaults to the rounded mean number of points across all streamlines. Pass
NULLto use these defaults explicitly.